@@ -104,10 +104,7 @@ class Gobits:
     @property
     def event_id(self):
         if self._context:
-            if isinstance(self._context, dict):
-                return self._context.get('event_id')
-            else:
-                return self._context.event_id
+            return self._context.event_id
         return None
 
     @property
